@@ -565,7 +565,7 @@ class MessageSummary(Table):
         icmp.register("Id", "icmp_id")
         icmp.register("Seq #", "icmp_seq")
         icmp.register("Mask", "icmp_mask");
-        icmp.register("Gateway Address", "icmp_gwaddr", socket.inet_ntoa)
+        icmp.register("Gateway Address", "icmp_gwaddr")
         icmp.register("Num address", "icmp_num_addrs")
         icmp.register("Wpa", "icmp_wpa")
         icmp.register("Lifetime", "icmp_lifetime")
@@ -794,37 +794,45 @@ class AlertSummary(TcpIpOptions, MessageSummary, view.View):
         elif service["protocol"]:
             self.newTableEntry("Protocol", service["protocol"])
                     
-    def buildDirection(self, alert, direction):
+    def buildDirection(self, direction):
         self.beginTable()
-        self.buildNode(alert["%s(0).node" % direction])
-        self.buildService(alert["%s(0).service" % direction])
+        self.buildNode(direction["node"])
+        self.buildService(direction["service"])
         self.endTable()
         
-        user = alert["%s(0).user" % direction]
+        user = direction["user"]
         if user:
             self.buildUser(user)
         
-        process = alert["%s(0).process" % direction]
+        process = direction["process"]
         if process:
             self.buildProcess(process)
         
     def buildSource(self, alert):
-        self.buildDirection(alert, "source")
-
+        i = 0
+        
+        for source in alert["source"]:
+            self.beginSection("Source(%d)" % i)
+            self.buildDirection(source)
+            self.endSection()
+            i += 1
+            
     def buildTarget(self, alert):
-        self.buildDirection(alert, "target")
+        i = 0
+        
+        for target in alert["target"]:
+            self.beginSection("Target(%d)" % i)
+            self.buildDirection(target)
 
-        for f in alert["target(0).file"]:
-            self.buildFile(f)
+            for f in target["file"]:
+                self.buildFile(f)
 
+            self.endSection()
+            i += 1
+            
     def buildSourceTarget(self, alert):
-        self.beginSection("Source")
         self.buildSource(alert)
-        self.endSection()
-
-        self.beginSection("Target")
         self.buildTarget(alert)
-        self.endSection()
 
     def getSectionName(self, alert):
         if alert["correlation_alert"]:
